package de.hsh.prog.v02;

import java.awt.Graphics;

/** Klasseninvariante: x&gt;=0 und y&gt;=0. */

public class Loc {
    private int x;
    private int y;

    /** Initialisiert das Objekt mit gegebenen Koordinatenwerten.
     *  @param initialX Vorbedingung: >= 0
     *  @param initialY Vorbedigung: >= 0. 
     *  @exception IllegalArgumentException falls einer der Eingabeparameter ung&uuml;ltig ist. 
     */
    public Loc(int initialX, int initialY) {
        setLocation(initialX, initialY);
    }

    /**
     * Initialisiert das Objekt mit den Koordinaten x=0, y=0
     */
    public Loc() {
        this(0, 0);
    }

    /**
     * Getter für x Wert
     */
    public int getX() {
        return x;
    }

    /**
     * Getter für y Wert
     */
    public int getY() {
        return y;
    }

    /**
     * Zeichnet den Punkt auf einer Graphic g mit Angabe der Koordinaten
     */
    public void draw(Graphics g) {
        g.fillOval(x, y, 3, 3);
        g.drawString("(" + x + ", " + y + ")", x, y);
    }

    /** Setzt die Koordinaten auf neue Werte.
     *  @param newx Vorbedingung: >= 0
     *  @param newy Vorbedigung: >= 0. 
     *  @exception IllegalArgumentException falls einer der Eingabeparameter ung&uuml;ltig ist. 
     */
    public void setLocation(int newx, int newy) {
        if (newx < 0 || newy < 0) {
            throw new IllegalArgumentException("x und y müssen >= 0 sein");
        }
        x= newx;
        y= newy;
    }

    /**
     * Verschiebt den Punkt um ein gewisses delta x und y
     */
    public void translate(int dx, int dy) {
        setLocation(x + dx, y + dy);
    }

    /**
     * Berechnet die Distanz zu einem weiteren Punkt
     */
    public double distance(Loc other) {
        int dx= x - other.x;
        int dy= y - other.y;
        return Math.sqrt(dx * dx + dy * dy);
    }

    /**
     * Berechnet die Distanz vom Nullpunkt (x=0, y=0)
     */
    public double distanceFromOrigin() {
        Loc origin= new Loc();
        return distance(origin);
    }

    /**
     * Gibt das Objekt als String zurück
     */
    public String toString() {
        return "(" + x + ", " + y + ")";
    }
    
    /**
     * Gibt die "Manhattan-Distanz" zwischen diesem und einem anderen Loc Objekt zurück
     */
    public int manhattanDistance(Loc l) {
        return Math.abs(this.x - l.x) + Math.abs(this.y - l.y);
    }
}


