package com.mymart;

/**
 * Klasse zum abspeichern eines Artikels
 * @author p8q-yhw-u1
 */
public class CartItem {
    private String name;
    private int quantity;
    private double pricePerUnit;
    
    /**
     * initialisiert einen einzukaufenden Artikel mit den gegebenen Daten
     * @param name der Name des Artikels
     * @param quantity die Anzahl der gekauften Artikel
     * @param pricePerUnit der Preis pro Artikel
     */
    public CartItem(String name, int quantity, double pricePerUnit) {
        this.name = name;
        setQuantity(quantity);
        this.pricePerUnit = pricePerUnit;
    }
    
    /**
     * Liefert den Gesamtpreis des Artikels.
     */
    public double getCost() {
        return this.quantity * this.pricePerUnit;
    }
    
    /**
     * Setzt die Anzahl der Artikel
     * @param quantity Anzahl der Artikel (muss mindestens 1 sein)
     */
    public void setQuantity(int quantity) {
        if (quantity <= 0) {
            throw new IllegalArgumentException("Die Anzahl (quantity) eines Artikels muss stehts >= 1 sein");
        }
        this.quantity = quantity;
    }
    
    /**
     * Gibt das Item in String Form zurück.
     */
    public String toString() {
        return String.format("%3d x %-30s   %10.2f  %10.2f%n", this.quantity, this.name, this.pricePerUnit, this.getCost());
    }
}