package de.hsh.prog.klasseline;

import java.awt.Graphics;


/**
 * Linie, bestehend aus Start- und Endpunkt
 * @author p8q-yhw-u1
 */
public class Line {
    private Loc p1;
    private Loc p2;
    
    /**
     * Erstellt ein Line Objekt aus Anfangs- und Endkoordinaten
     * @param x1 x von p1
     * @param y1 y von p1
     * @param x2 x von p2
     * @param y2 y von p2
     */
    public Line(int x1, int y1, int x2, int y2) {
        this.p1 = new Loc(x1, y1);
        this.p2 = new Loc(x2, y2);
    }
    /**
     * Erstellt ein Line Objekt aus Anfangs- und Endpunkt
     * @param p1 Startpunkt
     * @param p2 Endpunkt
     */
    public Line(Loc p1, Loc p2) {
        this(p1.getX(), p1.getY(), p2.getX(), p2.getY());
    }
    
    /**
     * Copy Konstruktor für ein Objekt der Line Klasse
     * @param l das zu kopierende Line Objekt
     * @param deep Tiefe (true) oder flache (false) Kopie
     */
    public Line(Line l, boolean deep) {
        if (deep) {
            this.p1 = new Loc(l.getP1());
            this.p2 = new Loc(l.getP2());
        } else {
            this.p1 = l.getP1();
            this.p2 = l.getP2();
        }
    }
    
    /**
     * @return Startpunkt
     */
    public Loc getP1() {
        return p1;
    }
    /**
     * @return Endpunkt
     */
    public Loc getP2() {
        return p2;
    }
    
    /**
     * Gibt das Line Objekt als String aus
     */
    public String toString() {
        return "[" + p1 + ", " + p2 + "]";
    }
    
    /**
     * @return Länge der Linie
     */
    public double getLength() {
        return p1.distance(p2);
    }
    
    /**
     * Zeichnet die Linie
     * @param g Die Graphics die zum Zeichnen der Linie genutzt werden soll
     */
    public void draw(Graphics g) {
        g.drawLine(p1.getX(), p1.getY(), p2.getX(), p2.getY());
    }
}
