package de.hsh.prog.klassedashedline;

import java.awt.Graphics;
import java.util.Arrays;

/**
 * Klasse zum speichern und Zeichnen einer gestrichelten Linie
 * @author p8q-yhw-u1
 *
 */
public class DashedLine extends Line {
    
    private int[] dashes;
    
    /**
     * Erstellt ein DashedLine Objekt
     * @param l1 Startpunkt der Linie
     * @param l2 Endpunkt der Linie
     * @param dashes Zeichenmuster, ein Integer Array von Pixel-Längen.
     * Geradzahlige Indexe => Strich, Ungradzahlige Indexe => Lücke
     */
    public DashedLine(Loc l1, Loc l2, int[] dashes) {
        super(l1, l2);
        
        if (dashes.length <= 0) {
            throw new IllegalArgumentException("dashes muss mindestens ein Element enthalten");
        }
        
        this.dashes = dashes;
    }
    
    /**
     * Zeichnet die gestrichelt Linie mit einem Graphics Objekt
     */
    @Override
    public void draw(Graphics g) {
        double x = this.getP1().getX();
        double y = this.getP1().getY();

        double totalLen = this.getP1().distance(this.getP2());
        
        double dx = this.getP2().getX() - x;
        double dy = this.getP2().getY() - y;
        
        double currLen = 0;
        int currDash = 0;
        
        while (currLen < totalLen) {
            
            double dashLen = dashes[currDash];
            
            if (dashLen + currLen > totalLen) {
                dashLen = totalLen - currLen;
            }
            
            double nextx = x + dx * dashLen / totalLen;
            double nexty = y + dy * dashLen / totalLen;
            
            if (currDash % 2 == 0) {
                new Line((int) x, (int) y, (int) nextx, (int) nexty).draw(g);
            }
            
            x = nextx;
            y = nexty;
            
            currLen += dashLen;
            currDash = (currDash + 1) % this.dashes.length;
        }
    }
    
    /**
     * Gibt die Linie in String-Form aus
     */
    @Override
    public String toString() {
        return "[" + super.toString() + ", dashes=" + Arrays.toString(dashes) + "]";
    }
    
}
